/******************************************************************************
 * $Workfile: BeanFactory.java $
 * $Revision: 3 $
 * $Author: Edaugherty $
 * $Date: 5/09/02 3:04p $
 *
 ******************************************************************************
 * Copyright (c) 2001-2002, Eric Daugherty
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, 
 * with or without modification, are permitted provided 
 * that the following conditions are met:
 * 
 *   Redistributions of source code must retain the above
 *   copyright notice, this list of conditions and the 
 *   following disclaimer. 
 * 
 *   Redistributions in binary form must reproduce the 
 *   above copyright notice, this list of conditions and 
 *   the following disclaimer in the documentation and/or 
 *   other materials provided with the distribution. 
 * 
 *   Neither the name of Eric Daugherty nor the names of its 
 *   contributors may be used to endorse or promote products 
 *   derived from this software without specific prior written 
 *   permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND 
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

package com.ericdaugherty.lib.bean;

//Java Imports
import java.lang.reflect.*;

//Apache Imports
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Provides a factory for dynamic JavaBean implementations.  The 
 * Dynamic Proxy implementation is defined by the <a href="BeanHandler.html">
 * BeanHandler</a> class.
 * <p>
 * Please refer to the <a href="package-summary.html#package_description">
 * package level documentation</a> for further information.
 * 
 * @author <a href="mailto:java@ericdaugherty.com">Eric Daugherty</a> (<a href="http://www.ericdaugherty.com/java/daughertylib">http://www.ericdaugherty.com/java/daughertylib</a>)
 */
public class BeanFactory
{
	/**
	 * Create a new dynamic implementation of the specified 'JavaBean' interface.
	 * 
	 * @param beanInterfaceClass the Java Interface to implement.
	 * @return dynamic implementation of the specified interface.
	 */
	public static Object createBean( Class beanInterfaceClass )
	{
        BeanHandler handler = new BeanHandler();
		
		return Proxy.newProxyInstance( beanInterfaceClass.getClassLoader(),
									   new Class[] { beanInterfaceClass },
									   handler );
	}
	
	/**
	 * Create a new dynamic implementation of the specified 'JavaBean' interfaces.
	 */
	public static Object createBean( Class[] beanInterfaceClasses )
	{
		BeanHandler handler = new BeanHandler();
		
		return Proxy.newProxyInstance( beanInterfaceClasses[0].getClassLoader(),
									   beanInterfaceClasses,
									   handler );
	}

    //***************************************************************
    // Variables

    /** Logger for this class.  */
    private static Log _log = LogFactory.getLog( BeanFactory.class );
}
